.. _`usage`:

Using the Paraview Plugins
==========================

This section will cover how to use the Paraview plugins, for both the GGD plugins, as 
well as loading non-GGD data.

GGD Readers
-----------

.. toctree::
   :maxdepth: 2

   ggd_reader
   jorek_reader

non-GGD Readers
---------------

.. toctree::
   :maxdepth: 2

   1d_profiles_reader
   profiles_2d_reader
   beam_reader
   los_reader
   position_reader
   wall_limiter_reader

Filters
-------

.. toctree::
   :maxdepth: 2

   1d_profiles_mapper
